@@ -20,7 +20,9 @@
 
 #include <stdarg.h>
 
+#include "gva-audit.h"
 #include "gva-db.h"
+#include "gva-mame.h"
 #include "gva-tree-view.h"
 #include "gva-ui.h"
 
@@ -106,6 +108,11 @@ gva_main_init (void)
                 gconf_bridge_get (), GVA_GCONF_WINDOW_PREFIX,
                 GTK_WINDOW (GVA_WIDGET_MAIN_WINDOW), TRUE, FALSE);
 
+#ifndef WITH_GNOME
+        /* Requires that we link against libgnome. */
+        gtk_action_set_sensitive (GVA_ACTION_CONTENTS, FALSE);
+#endif
+
         gtk_action_set_sensitive (GVA_ACTION_PROPERTIES, FALSE);
         gtk_action_set_sensitive (GVA_ACTION_RECORD, FALSE);
         gtk_action_set_sensitive (GVA_ACTION_START, FALSE);
@@ -116,7 +123,7 @@ gva_main_init (void)
         gtk_action_set_visible (GVA_ACTION_INSERT_FAVORITE, FALSE);
         gtk_action_set_visible (GVA_ACTION_REMOVE_FAVORITE, FALSE);
 
-	gtk_widget_show (GVA_WIDGET_MAIN_WINDOW);
+        gtk_widget_show (GVA_WIDGET_MAIN_WINDOW);
 }
 
 /**
@@ -139,10 +146,10 @@ gva_main_build_database (GError **error)
         GdkDisplay *display;
         GdkWindow *window;
         GvaProcess *process;
-        GvaProcess *process2;
+        GvaProcess *process2 = NULL;
         guint context_id;
         guint total_supported;
-        gboolean main_loop_quit;
+        gboolean main_loop_quit = FALSE;
         gboolean success = FALSE;
 
         /* XXX Comment this code! */
@@ -175,11 +182,11 @@ gva_main_build_database (GError **error)
         if (main_loop_quit)
                 goto exit;
 
-        process = gva_db_verify_romsets (error);
+        process = gva_audit_roms (error);
         if (process == NULL)
                 goto fail;
 
-        process2 = gva_db_verify_samplesets (error);
+        process2 = gva_audit_samples (error);
         if (process2 == NULL)
                 goto fail;
 
